@@ -19,7 +19,8 @@ from . import pygameutils
 from . import algorithms
 from . import mathlib
 from . import view3d
-from . import socket
+from . import socketutils
+from . import imageutils
 
 print("""
 Python module PumpkinPy
